<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="20"/>
        <location filename="../mainwindow.cpp" line="100"/>
        <source>MX Package Installer</source>
        <translation>MX paketų diegimo programa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="57"/>
        <source>Popular Applications</source>
        <translation>Populiarios programos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="83"/>
        <location filename="../mainwindow.cpp" line="103"/>
        <source>Package</source>
        <translation>Paketas</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="88"/>
        <location filename="../mainwindow.cpp" line="103"/>
        <source>Info</source>
        <translation>Informacija</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="93"/>
        <location filename="../mainwindow.ui" line="250"/>
        <location filename="../mainwindow.ui" line="653"/>
        <location filename="../mainwindow.ui" line="975"/>
        <location filename="../mainwindow.cpp" line="103"/>
        <source>Description</source>
        <translation>Aprašas</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="113"/>
        <location filename="../mainwindow.ui" line="216"/>
        <location filename="../mainwindow.ui" line="619"/>
        <location filename="../mainwindow.ui" line="944"/>
        <location filename="../mainwindow.ui" line="1208"/>
        <source>search</source>
        <translation>ieškoti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="123"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Manage popular packages&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Greyed out items have already been installed.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Tvarkyti populiarius paketus&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Pilka spalva atvaizduojami elementai jau yra įdiegti.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="153"/>
        <source>Stable Repo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="174"/>
        <location filename="../mainwindow.ui" line="564"/>
        <location filename="../mainwindow.ui" line="889"/>
        <location filename="../mainwindow.ui" line="1156"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Filter packages according to their status.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Filtruoti paketus atitinkamai pagal jų būseną.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="177"/>
        <location filename="../mainwindow.ui" line="181"/>
        <location filename="../mainwindow.ui" line="567"/>
        <location filename="../mainwindow.ui" line="571"/>
        <location filename="../mainwindow.ui" line="892"/>
        <location filename="../mainwindow.ui" line="896"/>
        <location filename="../mainwindow.cpp" line="2188"/>
        <source>All packages</source>
        <translation>Visi paketai</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="186"/>
        <location filename="../mainwindow.ui" line="576"/>
        <location filename="../mainwindow.ui" line="901"/>
        <location filename="../mainwindow.cpp" line="2202"/>
        <source>Installed</source>
        <translation>Įdiegti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="191"/>
        <location filename="../mainwindow.ui" line="581"/>
        <location filename="../mainwindow.ui" line="906"/>
        <location filename="../mainwindow.cpp" line="2200"/>
        <source>Upgradable</source>
        <translation>Naujintini</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="196"/>
        <location filename="../mainwindow.ui" line="586"/>
        <location filename="../mainwindow.ui" line="911"/>
        <location filename="../mainwindow.ui" line="1188"/>
        <location filename="../mainwindow.cpp" line="2167"/>
        <location filename="../mainwindow.cpp" line="2204"/>
        <location filename="../mainwindow.cpp" line="2293"/>
        <source>Not installed</source>
        <translation>Neįdiegti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="240"/>
        <location filename="../mainwindow.ui" line="643"/>
        <location filename="../mainwindow.ui" line="965"/>
        <source>Package Name</source>
        <translation>Paketo pavadinimas</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="245"/>
        <location filename="../mainwindow.ui" line="648"/>
        <location filename="../mainwindow.ui" line="970"/>
        <location filename="../mainwindow.ui" line="1243"/>
        <source>Version</source>
        <translation>Versija</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="277"/>
        <location filename="../mainwindow.ui" line="680"/>
        <location filename="../mainwindow.ui" line="1002"/>
        <source>Total packages:</source>
        <translation>Viso paketų:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="307"/>
        <location filename="../mainwindow.ui" line="710"/>
        <location filename="../mainwindow.ui" line="1032"/>
        <source>Installed:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="337"/>
        <location filename="../mainwindow.ui" line="740"/>
        <location filename="../mainwindow.ui" line="1062"/>
        <source>Upgradable:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="351"/>
        <location filename="../mainwindow.ui" line="1313"/>
        <source>Upgrade All</source>
        <translation>Naujinti visus</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="378"/>
        <location filename="../mainwindow.ui" line="767"/>
        <location filename="../mainwindow.ui" line="1089"/>
        <source>Hide library and developer packages</source>
        <translation>Slėpti bibliotekas ir plėtotojų paketus</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="400"/>
        <location filename="../mainwindow.ui" line="789"/>
        <location filename="../mainwindow.ui" line="1111"/>
        <source>Refresh list</source>
        <translation>Įkelti sąrašą iš naujo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="417"/>
        <location filename="../mainwindow.ui" line="594"/>
        <location filename="../mainwindow.ui" line="919"/>
        <location filename="../mainwindow.ui" line="1456"/>
        <source>Greyed out items have already been installed.</source>
        <translation>Pilka spalva pažymėti elementai jau yra įdiegti.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="473"/>
        <location filename="../mainwindow.ui" line="536"/>
        <location filename="../mainwindow.ui" line="856"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;= Upgradable package. Newer version available in selected repository.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;= Naujintinas paketas. Pasirinktoje saugykloje yra prieinama naujesnė versija.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="493"/>
        <source>MX Test Repo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="813"/>
        <source>Debian Backports</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1135"/>
        <source>Flatpaks</source>
        <translation>Flatpak paketai</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1159"/>
        <location filename="../mainwindow.ui" line="1163"/>
        <location filename="../mainwindow.cpp" line="2148"/>
        <source>All apps</source>
        <translation>Visos programos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1168"/>
        <location filename="../mainwindow.cpp" line="2153"/>
        <source>All runtimes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1173"/>
        <location filename="../mainwindow.cpp" line="2158"/>
        <source>All available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1178"/>
        <location filename="../mainwindow.cpp" line="2146"/>
        <location filename="../mainwindow.cpp" line="2288"/>
        <source>Installed apps</source>
        <translation>Įdiegtos programos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1183"/>
        <location filename="../mainwindow.cpp" line="2144"/>
        <source>Installed runtimes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1233"/>
        <source>Short Name</source>
        <translation>Trumpasis pavadinimas</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1238"/>
        <source>Full Package Name</source>
        <translation>Pilnas paketo pavadinimas</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1248"/>
        <source>Size</source>
        <translation>Dydis</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1292"/>
        <source>Total items </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1306"/>
        <source>Installed apps:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1359"/>
        <source>Advanced</source>
        <translation>Išplėstiniai</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1389"/>
        <source>Total installed size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1406"/>
        <location filename="../mainwindow.ui" line="1410"/>
        <source>For all users</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1415"/>
        <source>For current user</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1433"/>
        <source>Remote (repo):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1476"/>
        <location filename="../mainwindow.cpp" line="1975"/>
        <location filename="../mainwindow.cpp" line="2101"/>
        <source>Console Output</source>
        <translation>Pulto išvestis</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1482"/>
        <source>Enter</source>
        <translation>Enter (Įvedimas)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1493"/>
        <source>Respond here, or just press Enter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1549"/>
        <source>Uninstall</source>
        <translation>Šalinti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1556"/>
        <source>Alt+U</source>
        <translation>Alt+U</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1572"/>
        <source>About this application</source>
        <translation>Apie šią programą</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1575"/>
        <source>About...</source>
        <translation>Apie...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1582"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1630"/>
        <source>Display help </source>
        <translation>Rodyti žinyną</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1633"/>
        <source>Help</source>
        <translation>Žinynas</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1640"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1656"/>
        <location filename="../mainwindow.cpp" line="1878"/>
        <location filename="../mainwindow.cpp" line="2282"/>
        <location filename="../mainwindow.cpp" line="2285"/>
        <source>Install</source>
        <translation>Įdiegti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1663"/>
        <source>Alt+I</source>
        <translation>Alt+I</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1682"/>
        <source>Quit application</source>
        <translation>Išeiti iš programos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1685"/>
        <source>Close</source>
        <translation>Užverti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1692"/>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="154"/>
        <source>Uninstalling packages...</source>
        <translation>Šalinami paketai...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="159"/>
        <source>Running post-uninstall operations...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="177"/>
        <source>Refreshing sources...</source>
        <translation>Iš naujo įkeliami šaltiniai...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="190"/>
        <location filename="../mainwindow.cpp" line="945"/>
        <location filename="../mainwindow.cpp" line="1063"/>
        <location filename="../mainwindow.cpp" line="1179"/>
        <location filename="../mainwindow.cpp" line="1793"/>
        <location filename="../mainwindow.cpp" line="1808"/>
        <location filename="../mainwindow.cpp" line="1818"/>
        <location filename="../mainwindow.cpp" line="1946"/>
        <location filename="../mainwindow.cpp" line="1966"/>
        <location filename="../mainwindow.cpp" line="2372"/>
        <location filename="../mainwindow.cpp" line="2448"/>
        <location filename="../mainwindow.cpp" line="2475"/>
        <source>Error</source>
        <translation>Klaida</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="190"/>
        <source>There was a problem updating sources. Some sources may not have provided updates. For more info check: </source>
        <translation>Atnaujinant šaltinius, atsirado problemų. Gali būti, kad kai kurie šaltiniai nėra pateikę atnaujinimų. Išsamesnei informacijai, žiūrėkite: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="544"/>
        <source>Cancel</source>
        <translation>Atsisakyti</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="550"/>
        <source>Please wait...</source>
        <translation>Prašome palaukti...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="751"/>
        <location filename="../mainwindow.cpp" line="769"/>
        <source>Version </source>
        <translation>Versija </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="751"/>
        <source> in stable repo</source>
        <translation> stabilioje saugykloje</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="753"/>
        <source>Not available in stable repo</source>
        <translation>Neprieinama stabilioje saugykloje</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="763"/>
        <location filename="../mainwindow.cpp" line="2081"/>
        <source>Latest version </source>
        <translation>Naujausia versija </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="763"/>
        <location filename="../mainwindow.cpp" line="2081"/>
        <source> already installed</source>
        <translation> jau įdiegta</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="769"/>
        <source> installed</source>
        <translation> įdiegta</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="880"/>
        <source>You are about to use the MX Test repository, whose packages are provided for testing purposes only. It is possible that they might break your system, so it is suggested that you back up your system and install or update only one package at a time. Please provide feedback in the Forum so the package can be evaluated before moving up to Main.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="889"/>
        <source>You are about to use Debian Backports, which contains packages taken from the next Debian release (called &apos;testing&apos;), adjusted and recompiled for usage on Debian stable. They cannot be tested as extensively as in the stable releases of Debian and MX Linux, and are provided on an as-is basis, with risk of incompatibilities with other components in Debian stable. Use with care!</source>
        <translation>Jūs ketinate naudoti Debian naujų versijų paketus, kurie yra paimti iš kitos Debian laidos (pavadinimu &quot;testing&quot;), suderinti ir iš naujo sukompiliuoti naudojimui Debian stabiliose sistemose. Šie paketai negali būti taip plačiai išbandyti kaip stabiliose Debian ir MX Linux laidose, ir yra pateikiami esamu pavidalu, su nesuderinamumo su kitais Debian &quot;stable&quot; komponentais rizika. Naudokite atsargiai!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="897"/>
        <source>MX Linux includes this repository of flatpaks for the users&apos; convenience only, and is not responsible for the functionality of the individual flatpaks themselves. For more, consult flatpaks in the Wiki.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="906"/>
        <source>Warning</source>
        <translation>Įspėjimas</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="910"/>
        <source>Do not show this message again</source>
        <translation>Daugiau neberodyti šio pranešimo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="945"/>
        <location filename="../mainwindow.cpp" line="1063"/>
        <location filename="../mainwindow.cpp" line="1179"/>
        <source>Internet is not available, won&apos;t be able to download the list of packages</source>
        <translation>Internetas neprieinamas, nepavyks atsisiųsti paketų sąrašo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="950"/>
        <source>Installing packages...</source>
        <translation>Įdiegiami paketai...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="993"/>
        <source>Post-processing...</source>
        <translation>Po-apdorojimas...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1025"/>
        <source>Pre-processing for </source>
        <translation>Prieš-apdorojimas, skirtas </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1038"/>
        <source>Installing </source>
        <translation>Įdiegiama </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1045"/>
        <source>Post-processing for </source>
        <translation>Po-apdorojimas, skirtas </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1186"/>
        <source>Downloading package info...</source>
        <translation>Atsiunčiama paketo informacija...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1633"/>
        <source>Packages to be installed: </source>
        <translation>Paketai, kurie bus įdiegti: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1671"/>
        <source>Package info</source>
        <translation>Paketo informacija</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1789"/>
        <location filename="../mainwindow.cpp" line="1802"/>
        <location filename="../mainwindow.cpp" line="1815"/>
        <location filename="../mainwindow.cpp" line="1941"/>
        <location filename="../mainwindow.cpp" line="2368"/>
        <location filename="../mainwindow.cpp" line="2442"/>
        <location filename="../mainwindow.cpp" line="2469"/>
        <source>Done</source>
        <translation>Atlikta</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1789"/>
        <location filename="../mainwindow.cpp" line="1802"/>
        <location filename="../mainwindow.cpp" line="1815"/>
        <location filename="../mainwindow.cpp" line="1941"/>
        <location filename="../mainwindow.cpp" line="1959"/>
        <location filename="../mainwindow.cpp" line="2368"/>
        <location filename="../mainwindow.cpp" line="2442"/>
        <location filename="../mainwindow.cpp" line="2469"/>
        <source>Processing finished successfully.</source>
        <translation>Apdorojimas sėkmingai užbaigtas.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1793"/>
        <location filename="../mainwindow.cpp" line="1808"/>
        <location filename="../mainwindow.cpp" line="1818"/>
        <location filename="../mainwindow.cpp" line="2372"/>
        <location filename="../mainwindow.cpp" line="2448"/>
        <location filename="../mainwindow.cpp" line="2475"/>
        <source>Problem detected while installing, please inspect the console output.</source>
        <translation>Įdiegiant, aptikta problema, prašome panagrinėti pulto išvestį.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1828"/>
        <source>About %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1833"/>
        <source>%1 License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1847"/>
        <source>%1 Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About MX Package Installer</source>
        <translation type="vanished">Apie MX paketų diegimo programa</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1829"/>
        <source>Version: </source>
        <translation>Versija: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1830"/>
        <source>Package Installer for MX Linux</source>
        <translation>Paketų diegimo programa, skirta MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1832"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Autorių teisės (c) MX Linux</translation>
    </message>
    <message>
        <source>License</source>
        <translation type="vanished">Licencija</translation>
    </message>
    <message>
        <source>Changelog</source>
        <translation type="vanished">Keitinių žurnalas</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="vanished">&amp;Užverti</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1876"/>
        <source>Reinstall</source>
        <translation>Įdiegti iš naujo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1946"/>
        <source>We encountered a problem uninstalling, please check output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1959"/>
        <source>Success</source>
        <translation>Pavyko</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1966"/>
        <source>We encountered a problem uninstalling the program</source>
        <translation>Šalinant programą, susidurta su problema</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2057"/>
        <location filename="../mainwindow.cpp" line="2068"/>
        <source>Flatpak not installed</source>
        <translation>Flatpak neįdiegtas</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2057"/>
        <source>Flatpak is not currently installed.
OK to go ahead and install it?</source>
        <translation>Šiuo metu Flatpak nėra įdiegtas.
Galima pradėti ir įdiegti?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2068"/>
        <source>Flatpak was not installed</source>
        <translation>Flatpak nebuvo įdiegtas</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2089"/>
        <location filename="../mainwindow.cpp" line="2108"/>
        <source>Flathub remote failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2089"/>
        <location filename="../mainwindow.cpp" line="2108"/>
        <source>Flathub remote could not be added</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2097"/>
        <source>Needs re-login</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2097"/>
        <source>You might need to logout/login to see installed items in the menu</source>
        <translation>Jums gali tekti atsijungti/prisijungti, kad pamatytumėte meniu punktus</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2280"/>
        <source>Upgrade</source>
        <translation>Naujinti</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2402"/>
        <source>Quit?</source>
        <translation>Išeiti?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2403"/>
        <source>Process still running, quitting might leave the system in an unstable state.&lt;p&gt;&lt;b&gt;Are you sure you want to exit MX Package Installer?&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ManageRemotes</name>
    <message>
        <location filename="../remotes.cpp" line="14"/>
        <source>Manage Flatpak Remotes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="23"/>
        <source>For all users</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="24"/>
        <source>For current user</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="30"/>
        <source>enter Flatpak remote URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="33"/>
        <source>enter Flatpakref location to install app</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="35"/>
        <source>Add or remove flatpak remotes (repos), or install apps using flatpakref URL or path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="44"/>
        <source>Remove remote</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="49"/>
        <source>Add remote</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="54"/>
        <source>Install app</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="59"/>
        <source>Close</source>
        <translation>Užverti</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="81"/>
        <source>Not removable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="81"/>
        <source>Flathub is the main Flatpak remote and won&apos;t be removed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="97"/>
        <source>Error adding remote</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="97"/>
        <source>Could not add remote - command returned an error. Please double-check the remote address and try again</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="101"/>
        <source>Success</source>
        <translation>Pavyko</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="101"/>
        <source>Remote added successfully</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="61"/>
        <source>Unable to get exclusive lock</source>
        <translation>Nepavyko gauti išskirtinio užrakto</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="62"/>
        <source>Another package management application (like Synaptic or apt-get), is already running. Please close that application first</source>
        <translation>Jau yra vykdoma kita (tokia kaip Synaptic ar apt-get) paketų tvarkymo programa. Prašome, iš pradžių, užverti tą programą</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="89"/>
        <source>You must run this program as root.</source>
        <translation>Privalote paleisti šią programą kaip pagrindinis (root) naudotojas.</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="32"/>
        <source>License</source>
        <translation type="unfinished">Licencija</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="33"/>
        <location filename="../about.cpp" line="43"/>
        <source>Changelog</source>
        <translation type="unfinished">Keitinių žurnalas</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="34"/>
        <source>Cancel</source>
        <translation type="unfinished">Atsisakyti</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="51"/>
        <source>&amp;Close</source>
        <translation type="unfinished">&amp;Užverti</translation>
    </message>
</context>
</TS>
